@@ -94,12 +94,15 @@ CmdMapFunctionsList cmd_function[] =
 	{"toggle tracking mode",N_("toggle flat review/focus tracking mode")},	
 	{"flat review", 	N_("flat review")},
 	{"window hierarchy", 	N_("window hierarchy")},
+	{"read whole window", 	N_("read whole window")},
 	{"detailed informations", N_("detailed informations")},
 	{"do default action", 	N_("do default action")},
 	{"window overview", 	N_("window overview")},
 	{"find next",		N_("find next")},
 	{"find set", 		N_("find set")},
 	{"attributes at caret", N_("attributes at caret")},	
+	{"watch current object", N_("watch current object")},	
+	{"unwatch all objects", N_("unwatch all objects")},	
 
 	{"mouse left press", 	N_("mouse left press")},
 	{"mouse left click", 	N_("mouse left click")},
@@ -120,6 +123,11 @@ CmdMapFunctionsList cmd_function[] =
 	{"display left", 	N_("display left")},
 	{"display right", 	N_("display right")},
 
+	{"braille on/off",	N_("braille on/off")},
+	{"speech on/off",	N_("speech on/off")},
+	{"magnifier on/off",	N_("magnifier on/off")},
+	{"braille monitor on/off", N_("braille monitor on/off")},
+
 	{NULL,			NULL}
 	
     };
@@ -201,14 +209,14 @@ typedef enum
     USER_DEFINED
 }TypeOfUsingList;
 
-struct {
+static struct {
     KeyItem 		*current_keyitem;
     GtkTreeIter 	current_iter;
     GSList		*current_list;
     GtkTreeView		*current_tree_view;
     gboolean		current_is_new;
     TypeOfUsingList    	current_type;
-} current_item;
+} cmd_current_item;
     
 static GtkWidget	*w_user_keys = NULL;
 static GtkWidget	*w_layer_key = NULL;
@@ -332,7 +340,7 @@ cmdui_get_text_from_code (const gchar *str)
 				str[POS_DIGIT_3]);
 
     delimit = g_strrstr (str, KEY_NAME_SEPARATOR);
-    (const gchar*)tmp = str;
+    tmp = (gchar *)str;
     if (delimit)
 	tmp = delimit + 1;
 
@@ -382,7 +390,7 @@ cmdui_get_code_from_text (const gchar *str)
     }
     
     delimit = g_strrstr (str, KEY_SEPARATOR);
-    (const gchar*)tmp = str;
+    tmp = (gchar *)str;
     
     if (delimit)
 	tmp = delimit + 1;
@@ -432,8 +440,8 @@ cmdui_command_list_selection_add_func (GtkTreeModel 	*model,
     
     if (cmd_function[pos].descr)
     {
-	    (current_item.current_keyitem)->command_list = 
-		g_slist_prepend ((current_item.current_keyitem)->command_list, 
+	    (cmd_current_item.current_keyitem)->command_list = 
+		g_slist_prepend ((cmd_current_item.current_keyitem)->command_list, 
 				g_strdup (cmd_function [pos].name));
     }	
 }
@@ -447,38 +455,38 @@ cmdui_command_list_set_changes (void)
     GtkTreeSelection *selection = 
 	    gtk_tree_view_get_selection (GTK_TREE_VIEW (tv_cmd_list));	    
 
-    sru_return_val_if_fail (current_item.current_keyitem, FALSE);	    
+    sru_return_val_if_fail (cmd_current_item.current_keyitem, FALSE);	    
         		    
-    model = gtk_tree_view_get_model ( GTK_TREE_VIEW (current_item.current_tree_view));
+    model = gtk_tree_view_get_model ( GTK_TREE_VIEW (cmd_current_item.current_tree_view));
 
-    (current_item.current_keyitem)->command_list =
-	cmdconf_free_list_and_data ((current_item.current_keyitem)->command_list);
+    (cmd_current_item.current_keyitem)->command_list =
+	cmdconf_free_list_and_data ((cmd_current_item.current_keyitem)->command_list);
 
     gtk_tree_selection_selected_foreach (selection, 
     					cmdui_command_list_selection_add_func, 
 					NULL);
 
-    (current_item.current_keyitem)->command_list = 
-        cmdconf_check_integrity ((current_item.current_keyitem)->command_list);
+    (cmd_current_item.current_keyitem)->command_list = 
+        cmdconf_check_integrity ((cmd_current_item.current_keyitem)->command_list);
 	    
 	
-    if (!g_slist_length ((current_item.current_keyitem)->command_list))
+    if (!g_slist_length ((cmd_current_item.current_keyitem)->command_list))
     {
 	gn_show_message (_("No selected command!"));
 	return FALSE;
     }
 
-    txt = cmdconf_create_view_string ((current_item.current_keyitem)->command_list);
+    txt = cmdconf_create_view_string ((cmd_current_item.current_keyitem)->command_list);
 	
     sru_return_val_if_fail (txt, FALSE);
     sru_return_val_if_fail (GTK_IS_LIST_STORE (model), FALSE);
     
     gtk_list_store_set (GTK_LIST_STORE (model), 
-			&current_item.current_iter, 
+			&cmd_current_item.current_iter, 
 			FUNC_COLUMN, txt,
 			-1 );
 			
-    (current_item.current_keyitem)->commands = txt;
+    (cmd_current_item.current_keyitem)->commands = txt;
 	    
     cmdui_changes_set (TRUE);
     
@@ -526,8 +534,8 @@ cmdui_command_list_treeviews_set_current_value (void)
     if (!w_command_list) 
 	return;
 	
-    sru_return_if_fail (current_item.current_keyitem);
-    sru_return_if_fail ((current_item.current_keyitem)->key_code);
+    sru_return_if_fail (cmd_current_item.current_keyitem);
+    sru_return_if_fail ((cmd_current_item.current_keyitem)->key_code);
     
     model 	  = gtk_tree_view_get_model 	( GTK_TREE_VIEW (tv_cmd_list));
     selection     = gtk_tree_view_get_selection ( GTK_TREE_VIEW (tv_cmd_list));
@@ -538,7 +546,7 @@ cmdui_command_list_treeviews_set_current_value (void)
     
     valid = gtk_tree_model_get_iter_first (model, &iter);
     
-    if (!strcmp ((current_item.current_keyitem)->key_code, BLANK))
+    if (!strcmp ((cmd_current_item.current_keyitem)->key_code, BLANK))
 	return;
 	
     while (valid)
@@ -561,7 +569,7 @@ cmdui_command_list_treeviews_set_current_value (void)
 	if (cmd_function[pos].descr)
 	{
 	    GSList *elem = NULL;
-	    for (elem = (current_item.current_keyitem)->command_list ; elem ; elem = elem->next)
+	    for (elem = (cmd_current_item.current_keyitem)->command_list ; elem ; elem = elem->next)
 	    {
 	        if (!strcmp (cmd_function[pos].name,
 	    		    (gchar*)elem->data))
@@ -614,22 +622,22 @@ cmdui_response_command_list_event (GtkDialog *dialog,
     {
 	if (!cmdui_command_list_set_changes ())
 	{
-	    cmdui_command_list_restore_state (current_item.current_tree_view,
-					      current_item.current_iter,
-					      current_item.current_list,
-					      current_item.current_keyitem,
-					      current_item.current_is_new,
-					      current_item.current_type);
+	    cmdui_command_list_restore_state (cmd_current_item.current_tree_view,
+					      cmd_current_item.current_iter,
+					      cmd_current_item.current_list,
+					      cmd_current_item.current_keyitem,
+					      cmd_current_item.current_is_new,
+					      cmd_current_item.current_type);
 	}
     }	
     if (response_id == GTK_RESPONSE_CANCEL)
     {
-	    cmdui_command_list_restore_state (current_item.current_tree_view,
-					      current_item.current_iter,
-					      current_item.current_list,
-					      current_item.current_keyitem,
-					      current_item.current_is_new,
-					      current_item.current_type);
+	    cmdui_command_list_restore_state (cmd_current_item.current_tree_view,
+					      cmd_current_item.current_iter,
+					      cmd_current_item.current_list,
+					      cmd_current_item.current_keyitem,
+					      cmd_current_item.current_is_new,
+					      cmd_current_item.current_type);
     }
     gtk_widget_hide ((GtkWidget*)dialog);	
 }
@@ -785,7 +793,7 @@ cmdui_get_key (void)
     
     line = alt || shift || ctrl ;
     
-    (const gchar*)key = cmdui_get_key_keystring (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cb_key_list)->entry)));
+    key = (gchar *)cmdui_get_key_keystring (gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (cb_key_list)->entry)));
     
     if (!key || strlen (key) == 0)
 	return rv;
@@ -818,7 +826,7 @@ cmdui_response_user_keys_event (GtkDialog *dialog,
 	
 	if (key_code)
 	{
-	    current_item.current_type = USER_DEFINED;
+	    cmd_current_item.current_type = USER_DEFINED;
 	    
 	    user_def_list = cmdui_add_item_to_list (GTK_TREE_VIEW (tv_user_def), 
 						    user_def_list,
@@ -909,7 +917,7 @@ cmdui_response_layer_key_event (GtkDialog *dialog,
 	gchar *layer_key = cmdui_get_layer_key ();
 	if (layer_key)
 	{
-	    current_item.current_type = KEY_PAD;
+	    cmd_current_item.current_type = KEY_PAD;
 	    key_pad_list =
 		    cmdui_add_item_to_list (GTK_TREE_VIEW (tv_key_pad), 
 					    key_pad_list,
@@ -1143,11 +1151,11 @@ cmdui_add_item_to_list (GtkTreeView *tree_view,
     g_free (tmp);
     gtk_tree_selection_select_iter (selection, &iter);
     
-    current_item.current_keyitem = new_code;
-    current_item.current_iter = iter;
-    current_item.current_list = list;
-    current_item.current_tree_view = tree_view;
-    current_item.current_is_new = TRUE;
+    cmd_current_item.current_keyitem = new_code;
+    cmd_current_item.current_iter = iter;
+    cmd_current_item.current_list = list;
+    cmd_current_item.current_tree_view = tree_view;
+    cmd_current_item.current_is_new = TRUE;
     cmdui_changes_set (TRUE);
     /* load command list to add command to new key */
     cmdui_load_command_list ();
@@ -1204,11 +1212,11 @@ cmdui_main_window_modify_item_to_list (GtkTreeView *tree_view,
     if (!new_code)
 	return list;
 	
-    current_item.current_keyitem = new_code;
-    current_item.current_iter = iter;
-    current_item.current_list = list;
-    current_item.current_tree_view = tree_view;
-    current_item.current_is_new = FALSE;
+    cmd_current_item.current_keyitem = new_code;
+    cmd_current_item.current_iter = iter;
+    cmd_current_item.current_list = list;
+    cmd_current_item.current_tree_view = tree_view;
+    cmd_current_item.current_is_new = FALSE;
     cmdui_load_command_list ();
 
     return list;
@@ -1233,7 +1241,7 @@ static void
 cmdui_main_window_key_pad_modify_clicked (GtkWidget *button,
 	        	    		  gpointer  user_data)
 {
-    current_item.current_type = KEY_PAD;
+    cmd_current_item.current_type = KEY_PAD;
     key_pad_list = 
 	cmdui_main_window_modify_item_to_list (GTK_TREE_VIEW (tv_key_pad), 
 						key_pad_list);
@@ -1244,7 +1252,7 @@ static void
 cmdui_main_window_user_modify_clicked (GtkWidget 	*button,
 	            			gpointer 	user_data)
 {
-    current_item.current_type = USER_DEFINED;
+    cmd_current_item.current_type = USER_DEFINED;
     user_def_list =
 	cmdui_main_window_modify_item_to_list (GTK_TREE_VIEW (tv_user_def), 
 						user_def_list);
@@ -1267,7 +1275,7 @@ cmdui_main_window_key_pad_row_activated_cb (GtkTreeView       *tree_view,
                 			    GtkTreePath       *path,
 					    GtkTreeViewColumn *column)
 {
-    current_item.current_type = KEY_PAD;
+    cmd_current_item.current_type = KEY_PAD;
     key_pad_list = 
 	cmdui_main_window_modify_item_to_list (GTK_TREE_VIEW (tv_key_pad), 
 						key_pad_list);
@@ -1289,7 +1297,7 @@ cmdui_main_window_user_def_row_activated_cb (GtkTreeView      *tree_view,
                 			    GtkTreePath       *path,
 					    GtkTreeViewColumn *column)
 {
-    current_item.current_type = USER_DEFINED;
+    cmd_current_item.current_type = USER_DEFINED;
     user_def_list =
 	cmdui_main_window_modify_item_to_list (GTK_TREE_VIEW (tv_user_def), 
 						user_def_list);
@@ -1442,7 +1450,7 @@ cmdui_main_window_response_event (GtkDialog *dialog,
 	}
         break;
     case GTK_RESPONSE_HELP:
-	    gn_load_help ("gnopernicus-command-mapping");
+	    gn_load_help ("gnopernicus-cm-prefs");
 	break;	
     case GTK_RESPONSE_CANCEL:
     default:
@@ -1631,6 +1639,3 @@ cmdui_load_user_properties (GtkWidget *parent_window)
 		    
     return TRUE;
 }
-
-
-
