@@ -179,6 +179,49 @@ gnopiconf_set_int (gint val,
     return ret;
 }
 
+gboolean
+gnopiconf_set_double (gdouble val, 
+		      const gchar *key)
+{
+    GError *error = NULL;
+    gboolean  ret = TRUE;
+    
+    sru_return_val_if_fail ( key != NULL, FALSE );
+    sru_return_val_if_fail ( gnopernicus_client != NULL, FALSE );
+    sru_return_val_if_fail ( gconf_client_key_is_writable (gnopernicus_client, key, NULL), FALSE);
+
+#ifdef SAVE_SCHEMA_TEMPLATE
+    gnopiconf_create_schema_entry (key, "float", g_strdup_printf ("%f",val), NULL);
+#endif
+
+    ret  = gconf_client_set_float (gnopernicus_client, key, val, &error);
+
+    g_message ("setting key %s to float %f", key, val);
+
+    if (error != NULL)
+    {
+	sru_warning (_(error->message));
+	g_error_free (error);
+	error = NULL;
+    }
+    
+    return ret;
+}
+
+gboolean
+gnopiconf_set_double_in_section (gdouble val, 
+				 const gchar *section, 
+				 const gchar *key)
+{
+    gchar *path = NULL;
+    sru_return_val_if_fail (key != NULL, FALSE);
+    sru_return_val_if_fail (section != NULL, FALSE);
+    path = gconf_concat_dir_and_key (section, key);
+    gnopiconf_set_double (val, path);
+    g_free (path);
+    return TRUE;
+}
+
 gboolean
 gnopiconf_set_int_in_section (gint val, 
 			      const gchar *section, 
@@ -193,7 +236,6 @@ gnopiconf_set_int_in_section (gint val,
     return TRUE;
 }
 
-
 gboolean
 gnopiconf_set_string (const gchar *val, 
 		      const gchar *key)
@@ -336,6 +378,76 @@ gnopiconf_get_int_with_default (const gchar *key,
     }    
 }
 
+gdouble
+gnopiconf_get_double_with_default (const gchar *key, 
+				   gdouble default_value)
+{
+    GError *error = NULL;
+    GConfValue *value = NULL;
+    gdouble ret_val;
+    gchar *key_error = NULL;
+    
+    sru_return_val_if_fail (key != NULL, default_value );
+    sru_return_val_if_fail (gnopernicus_client != NULL, default_value );
+    if (!gconf_valid_key (key, &key_error))
+    {
+	sru_error (key_error);
+	g_free (key_error);
+	return FALSE;
+    }    
+
+    value = gconf_client_get (gnopernicus_client, key, &error);
+    
+    ret_val = default_value;
+    
+    if (value != NULL && error == NULL)
+    {	
+	if (gnopiconf_check_type (key, value, GCONF_VALUE_FLOAT, &error))
+    	    ret_val = gconf_value_get_float (value);
+        else
+	{
+    	    sru_warning (_("Invalid type of key: %s."), key);
+	    if (!gnopiconf_set_double (ret_val, key))
+	        sru_warning (_("Failed to set value: %f."), ret_val);
+	}
+	    
+	gconf_value_free (value);
+		
+        return ret_val;
+    }
+    else
+    {
+	if (error != NULL)
+	{
+	    sru_warning (_(error->message));
+	    g_error_free (error);
+	    error = NULL;
+	}
+
+	    
+	if (!gnopiconf_set_double (default_value, key))
+	    sru_warning (_("Failed to set value: %f."), default_value);
+		
+        return default_value;
+    }    
+}
+
+gdouble
+gnopiconf_get_double_from_section_with_default (const gchar *section,
+						const gchar *key, 
+						gdouble default_value)
+{
+    gchar *path = NULL;
+    gint  return_value;
+    sru_return_val_if_fail (key != NULL, default_value);
+    sru_return_val_if_fail (section != NULL, default_value);
+    path = gconf_concat_dir_and_key (section, key);
+    return_value = gnopiconf_get_double_with_default (path, default_value);
+    g_free (path);
+    return return_value;
+}
+
+
 gint 
 gnopiconf_get_int_from_section_with_default (const gchar *section,
 					     const gchar *key, 
