@@ -641,17 +641,17 @@ src_braille_translation_table_exist (const gchar *table)
 gboolean
 src_braille_restart ()
 {
+    gchar *device = g_strdup (src_braille->device);
+    gint port = src_braille->port;
+
     if (src_use_braille)
-    {
-	gchar *device = g_strdup (src_braille->device);
-	gint port = src_braille->port;
-	/* terminate Braille */
 	src_braille_terminate ();
     	/* and then start it again */
-	src_braille->device = device;
-	src_braille->port = port;	
-	src_use_braille = src_braille_init ();
-    }
+	
+    src_braille->device = device;
+    src_braille->port = port;	
+    src_use_braille = src_braille_init ();
+
     if (src_use_braille_monitor)
     {
     }
@@ -663,7 +663,11 @@ extern void brl_xml_input_proc (gchar *, gint);
 static void
 src_braille_exited (gint signal)
 {
-    if (signal == SIGTERM)
+    if (signal == SIGTERM ||
+	signal == SIGQUIT ||
+	signal == SIGINT  ||
+	signal == SIGKILL ||
+	signal == SIGSEGV)
     {
 	kill (src_brlmon_pid, SIGTERM);
 	exit (1);
@@ -674,6 +678,11 @@ gboolean
 brl_mon_run_process (void)
 {
     signal (SIGTERM, src_braille_exited);
+    signal (SIGQUIT, src_braille_exited);
+    signal (SIGINT, src_braille_exited);
+    signal (SIGKILL, src_braille_exited);
+    signal (SIGSEGV, src_braille_exited);
+
     if (g_file_test ("../brlmon/brlmonitor", G_FILE_TEST_EXISTS) &&
         g_file_test ("../brlmon/brlmonitor", G_FILE_TEST_IS_EXECUTABLE) &&
         g_file_test ("../brlmon/brlmonitor", G_FILE_TEST_IS_REGULAR))
@@ -753,6 +762,8 @@ src_braille_setting_new ()
 static void
 src_braille_load_values (SRCBraille *braille)
 {
+    gint default_port = DEFAULT_BRAILLE_PORT_NO;
+
     sru_assert (braille);
     
     if (!braille->device)
@@ -763,20 +774,16 @@ src_braille_load_values (SRCBraille *braille)
 					      default_device);
     }
         
-    if (MIN_BRAILLE_PORT > braille->port || 
-	MAX_BRAILLE_PORT < braille->port)
-    {
-	gint default_port = DEFAULT_BRAILLE_PORT_NO;
-	GET_BRAILLE_CONFIG_DATA_WITH_DEFAULT (BRAILLE_PORT_NO, CFGT_INT, 
+    
+    GET_BRAILLE_CONFIG_DATA_WITH_DEFAULT (BRAILLE_PORT_NO, CFGT_INT, 
 					      &braille->port, 
 					      &default_port);
     
-	if (MIN_BRAILLE_PORT > braille->port || 
-	    MAX_BRAILLE_PORT < braille->port) 
-	{
-    	    braille->port = DEFAULT_BRAILLE_PORT_NO;
-    	    SET_BRAILLE_CONFIG_DATA (BRAILLE_PORT_NO, CFGT_INT, &braille->port);
-	}					  
+    if (MIN_SERIAL_PORT_NO > braille->port || 
+    	    MAX_SERIAL_PORT_NO < braille->port) 
+    {
+	braille->port = DEFAULT_BRAILLE_PORT_NO;
+    	SET_BRAILLE_CONFIG_DATA (BRAILLE_PORT_NO, CFGT_INT, &braille->port);
     }    
     
     gchar *default_braille_transaltion_table = DEFAULT_BRAILLE_TRANSLATION;
