@@ -39,6 +39,11 @@
 #include "screen-review.h"
 #include <libxml/parser.h>
 
+/* mouse motion idle support */
+#define SRC_MOUSE_MOVED_TIMEOUT		300 /* ms */
+static gboolean src_mouse_is_moving = FALSE;
+static guint mouse_stopped_moving_timeout_handler = 0;
+static guint mouse_is_moving_idle_handler = 0;
 
 gboolean login_time;
 
@@ -55,7 +60,7 @@ gboolean src_enable_format_string = FALSE;
 gint src_caret_position;
 
 gchar *braille_device = NULL;
-gint   braille_port;
+gint   braille_port = -1;
 
 extern gchar *scroll;
 extern gint old_offset;
@@ -261,8 +266,7 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 	{
 	    SRObjectRoles role;
 	    sro_get_role (obj, &role, SR_INDEX_CONTAINER);
-	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0 ||
-		strcmp (reason, "object:context-switched") == 0)
+	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0)
 	    {
 		if (role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
@@ -296,6 +300,9 @@ src_present_real_sro_for_magnifier (SRObject *obj, gchar *reason)
     if (src_use_speech && srl_is_object_watched (obj))
 	return;
 
+    if (src_mouse_is_moving)
+	return;
+
     txt = src_presentation_sro_get_pres_for_device (obj, reason, "magnifier");
     if (txt)
     {
@@ -394,7 +401,7 @@ src_present_crt_window ()
 	    else if (strcmp (reason, "window:rename") == 0)
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_LOW, TRUE);
 	    else if (strcmp (reason, "object:context-switched") == 0)
-	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, FALSE);
+	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
 	    else
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
 	}
@@ -1986,6 +1993,27 @@ src_process_tooltip_event (SREvent *event,
     }
 }
 
+static gboolean
+src_mouse_moved_timeout (gpointer data)
+{
+    src_mouse_is_moving = FALSE;
+    return FALSE;
+}
+
+static gboolean
+src_mouse_moved_set_timeout (gpointer data)
+{
+    if (mouse_stopped_moving_timeout_handler) 
+    {
+	g_source_remove (mouse_stopped_moving_timeout_handler);
+    }
+    mouse_stopped_moving_timeout_handler = 
+	g_timeout_add (SRC_MOUSE_MOVED_TIMEOUT, src_mouse_moved_timeout, NULL);
+
+    mouse_is_moving_idle_handler = 0;
+    return FALSE;
+}
+
 static void
 src_process_mouse_event (SREvent *event,
 		 unsigned long flags)
@@ -1994,7 +2022,12 @@ src_process_mouse_event (SREvent *event,
 
     if (!src_use_magnifier)
 	return;
-	
+
+    src_mouse_is_moving = TRUE;
+    if (!mouse_is_moving_idle_handler)
+    {
+	mouse_is_moving_idle_handler = g_idle_add (src_mouse_moved_set_timeout, NULL);
+    }
     if (sre_get_event_data (event, (void**)&point))
     {
 	gchar *magout;
@@ -2318,7 +2351,7 @@ src_init(const gchar *mouse_tracking,
     if (braille_device)
 	src_braille_set_device (braille_device);
     
-    if (braille_port)
+    if (braille_port != -1)
 	src_braille_set_port_no (braille_port);
     /* initialize 
     
@@ -2383,6 +2416,7 @@ src_init(const gchar *mouse_tracking,
     src_crt_sro = NULL;
     src_crt_tooltip = NULL;
     src_crt_window = NULL;
+    src_mouse_is_moving = FALSE;
 
     src_message = NULL;
 
@@ -2709,8 +2743,8 @@ main (gint argc,
     src_use_magnifier = (disable_magnifier ? FALSE :
 			(enable_magnifier  ? TRUE : -1));
 
-    if (braille_port <= MIN_BRAILLE_PORT && 
-	braille_port >= MAX_BRAILLE_PORT)
+    if (braille_port < MIN_SERIAL_PORT_NO ||
+	braille_port > MAX_SERIAL_PORT_NO)
     {
 	braille_port = DEFAULT_BRAILLE_PORT_NO;
     }
